{% extends 'base.html' %} {% block scripts %}
<script>
	$(function () {});
</script>

{% endblock %} {% block header %}
<h1>
	{% block title %} {# MSG: Title for the log in page for admins. #} {% trans %}Login{% endtrans %} {% endblock %}
</h1>
{% endblock %} {% block content %} {# MSG: Title fo the form to enter the administrator password. #}
<p>{% trans %}Enter the administrator password{% endtrans %}</p>
<form action="{{ url_for('admin.auth') }}" method="post">
	<input type="hidden" name="next" value="{{ request.args.get('next', '/') }}" />
	<div class="field has-addons mb-2">
		<div class="control" style="width: 100%; max-width: 350px">
			<input type="password" name="admin_password" class="input" />
		</div>
		<div class="control">
			{# MSG: Text on submit button for the admin login form. #}
			<button class="button is-rounded is-primary">{% trans %}Login{% endtrans %}</button>
		</div>
	</div>
</form>

{% endblock %}
